Dialects — SQLAlchemy 0.8 Documentation

# SQLAlchemy 0.8 Documentation

Search:
Release: 0.8.2 | Release Date: July 3, 2013

# Dialects

The dialect is the system SQLAlchemy uses to communicate with various types of DBAPI implementations and databases. The sections that follow contain reference documentation and notes specific to the usage of each backend, as well as notes for the various DBAPIs.

All dialects require that an appropriate DBAPI driver is installed.

## Included Dialects

- Drizzle
- Firebird
- Informix
- Microsoft SQL Server
- MySQL
- Oracle
- PostgreSQL
- SQLite
- Sybase

## External Dialects

Changed in version 0.8: As of SQLAlchemy 0.8, several dialects have been moved to external projects, and dialects for new databases will also be published as external projects. The rationale here is to keep the base SQLAlchemy install and test suite from growing inordinately large.

The “classic” dialects such as SQLite, MySQL, Postgresql, Oracle, SQL Server, and Firebird will remain in the Core for the time being.

Current external dialect projects for SQLAlchemy include:

- ibm_db_sa - driver for IBM DB2, developed jointly by IBM and SQLAlchemy developers.
- sqlalchemy-access - driver for Microsoft Access.
- sqlalchemy-akiban - driver and ORM extensions for the Akiban database.
- sqlalchemy-cubrid - driver for the CUBRID database.
- sqlalchemy-maxdb - driver for the MaxDB database.
- CALCHIPAN - Adapts Pandas dataframes to SQLAlchemy.